# 更改日志

## 0.6.0

- 添加获取任务、执行lua代码方法
- 修复add_signal、rerun_task 参数错误
- 添加单元测试
- 修复Robot run一直不返回值 bug
- 去除一些无效的 _sync调用
- 添加方法注释与类型注释
- 添加类型：RobotIOData、IOItem、RobotData、RobotPoseData、PVAT
- 自动生成API文档

## 0.6.1

- 修复模拟信号类型错误
